#EasyIBKR 

A helper module which makes automating trades using IBKR and Python MUCH easier through helper functions 
which sort through the confusing syntax elements.

Note: This build is based on ib_insync, though this may be updated to the newer maintained async version

## Installation

```Bash
pip install easyIBKR 

